@@ -36,6 +36,7 @@ mod extern_rust_method_swift_class_placement_codegen_tests;
 mod extern_rust_opaque_type_codegen_tests;
 mod function_attribute_codegen_tests;
 mod option_codegen_tests;
+mod shared_struct_codegen_tests;
 mod string_codegen_tests;
 
 /// Test code generation for freestanding Swift function that takes an opaque Rust type argument.
@@ -202,10 +203,8 @@ mod extern_rust_fn_return_vec_of_opaque_rust_type {
                 pub extern "C" fn _get(vec: *const Vec<super::MyRustType>, index: usize) -> *const super::MyRustType {
                     let vec = unsafe { & *vec };
                     if let Some(val) = vec.get(index) {
-                        swift_bridge::option::_set_option_return(true);
                         val as *const super::MyRustType
                     } else {
-                        swift_bridge::option::_set_option_return(false);
                         std::ptr::null()
                     }
                 }
@@ -215,10 +214,8 @@ mod extern_rust_fn_return_vec_of_opaque_rust_type {
                 pub extern "C" fn _get_mut(vec: *mut Vec<super::MyRustType>, index: usize) -> *mut super::MyRustType {
                     let vec = unsafe { &mut *vec };
                     if let Some(val) = vec.get_mut(index) {
-                        swift_bridge::option::_set_option_return(true);
                         val as *mut super::MyRustType
                     } else {
-                        swift_bridge::option::_set_option_return(false);
                         std::ptr::null::<super::MyRustType>() as *mut super::MyRustType
                     }
                 }
@@ -234,10 +231,8 @@ mod extern_rust_fn_return_vec_of_opaque_rust_type {
                 pub extern "C" fn _pop(vec: *mut Vec<super::MyRustType>) -> *mut super::MyRustType {
                     let vec = unsafe { &mut *vec };
                     if let Some(val) = vec.pop() {
-                        swift_bridge::option::_set_option_return(true);
                         Box::into_raw(Box::new(val))
                     } else {
-                        swift_bridge::option::_set_option_return(false);
                         std::ptr::null::<super::MyRustType>() as *mut super::MyRustType
                     }
                 }
@@ -386,6 +381,7 @@ enum ExpectedSwiftCode {
     ExactAfterTrim(&'static str),
     ContainsAfterTrim(&'static str),
     DoesNotContainAfterTrim(&'static str),
+    DoesNotContainManyAfterTrim(Vec<&'static str>),
     ContainsManyAfterTrim(Vec<&'static str>),
     /// Skip testing Swift code
     // We use a variant instead of Option<ExpectCHeader> as not to make it seem like no Swift code
@@ -398,6 +394,7 @@ enum ExpectedCHeader {
     ExactAfterTrim(&'static str),
     ContainsAfterTrim(&'static str),
     DoesNotContainAfterTrim(&'static str),
+    DoesNotContainManyAfterTrim(Vec<&'static str>),
     /// Skip testing C header
     // We use a variant instead of Option<ExpectCHeader> as not to make it seem like no C header
     // got generated.
@@ -451,17 +448,25 @@ impl CodegenTest {
                     expected_contained_swift,
                 );
             }
+            ExpectedSwiftCode::ContainsManyAfterTrim(many) => {
+                for expected_contained_swift in many {
+                    assert_trimmed_generated_contains_trimmed_expected(
+                        &swift,
+                        expected_contained_swift,
+                    );
+                }
+            }
             ExpectedSwiftCode::DoesNotContainAfterTrim(expected_not_contained_swift) => {
                 assert_trimmed_generated_does_not_contain_trimmed_expected(
                     &swift,
                     expected_not_contained_swift,
                 );
             }
-            ExpectedSwiftCode::ContainsManyAfterTrim(many) => {
-                for expected_contained_swift in many {
-                    assert_trimmed_generated_contains_trimmed_expected(
+            ExpectedSwiftCode::DoesNotContainManyAfterTrim(many) => {
+                for expected_not_contained in many {
+                    assert_trimmed_generated_does_not_contain_trimmed_expected(
                         &swift,
-                        expected_contained_swift,
+                        expected_not_contained,
                     );
                 }
             }
@@ -478,6 +483,11 @@ impl CodegenTest {
             ExpectedCHeader::DoesNotContainAfterTrim(expected) => {
                 assert_trimmed_generated_does_not_contain_trimmed_expected(&c_header, expected);
             }
+            ExpectedCHeader::DoesNotContainManyAfterTrim(many) => {
+                for expected in many {
+                    assert_trimmed_generated_does_not_contain_trimmed_expected(&c_header, expected);
+                }
+            }
             ExpectedCHeader::SkipTest => {}
         };
     }
